xquery version "3.1";

(: 
 : Module for app-specific template functions
 :
 : Add your own templating functions here, e.g. if you want to extend the template used for showing
 : the browsing view.
 :)
module namespace app="teipublisher.com/app";

import module namespace templates="http://exist-db.org/xquery/html-templating";
import module namespace config="http://www.tei-c.org/tei-simple/config" at "config.xqm";
import module namespace nav="http://www.tei-c.org/tei-simple/navigation/tei" at "navigation-tei.xql";

import module namespace tpu="http://www.tei-c.org/tei-publisher/util" at "../util.xql";
import module namespace query="http://www.tei-c.org/tei-simple/query" at "../../query.xql";
import module namespace kwic="http://exist-db.org/xquery/kwic" at "resource:org/exist/xquery/lib/kwic.xql";

import module namespace console="http://exist-db.org/xquery/console";


declare namespace tei="http://www.tei-c.org/ns/1.0";

declare
    %templates:wrap
function app:foo($node as node(), $model as map(*)) {
    <p>Dummy templating function.</p>
};


(:declare function app:searchperson($node as node(), $model as map(*)) {

let $c := collection ($config:data-root)

for $i in $c//tei:persName
return $i

};:)


(:declare
    %templates:wrap
function app:list-person($node as node(), $model as map(*), $ref as xs:string?) {
    (:for $hit in collection(concat($config:app-root, '/data/'))//tei:TEI[.//tei:ptr[@target=concat('#',$ref)]]:)
    for $hit in collection(concat($config:app-root, '/data/'))//tei:TEI[.//tei:persName[@ref=concat('#',$ref)]]
        let $app := request:get-context-path() || substring-after($config:app-root, "/db")
        let $docId := config:get-identifier($hit)
        let $link := root($hit)//tei:idno[@type='invNo'][parent::tei:msIdentifier]
        let $title := normalize-space(nav:get-document-title($model,$hit))
        return
            <span>{$hit}<a href="{$app}/{$docId}" title="{$title}">{$link}</a></span>
};:)


declare function app:searchperson($node as node(), $model as map(*)) {
    (:If there is no query string, fill up the map with existing values:)
   (:if (empty($request?parameters?query))
    then
        app:show-hits($request, session:get-attribute($config:session-prefix || ".hits"), session:get-attribute($config:session-prefix || ".docs"))
    else:)
        (:Otherwise, perform the query.:)
        (: Here the actual query commences. This is split into two parts, the first for a Lucene query and the second for an ngram query. :)
        (:The query passed to a Luecene query in ft:query is an XML element <query> containing one or two <bool>. The <bool> contain the original query and the transliterated query, as indicated by the user in $query-scripts.:)
        let $hitsAll :=
                (:If the $query-scope is narrow, query the elements immediately below the lowest div in tei:text and the four major element below tei:teiHeader.:)
                (:for $hit in collection ($config:data-root)//tei:persName[@ref and ancestor:: tei:div[@type="transl-text" ]] :)
                for $hit at $count in collection ($config:data-root)//tei:persName[@type="myth"]/text()
                order by $hit ascending(:ft:score($hit) descending:)
                return 
                   (:if ($hit/string() != collection ($config:data-root)//tei:persName[@type="myth"][$count -1]/string()) then:)
                    $hit
                    (:else():)
        let $hitCount := count($hitsAll)
        let $hits := if ($hitCount > 1000) then subsequence($hitsAll, 1, 1000) else $hitsAll
        (:Store the result in the session.:)
        let $store := (
            session:set-attribute($config:session-prefix || ".hits", $hitsAll),
            session:set-attribute($config:session-prefix || ".hitCount", $hitCount)
        )
        return
        (:console:log($hits):)
            app:show-hits($model, $hits, "gh")
};


declare function app:searchplace($node as node(), $model as map(*)) {
    (:If there is no query string, fill up the map with existing values:)
   (:if (empty($request?parameters?query))
    then
        app:show-hits($request, session:get-attribute($config:session-prefix || ".hits"), session:get-attribute($config:session-prefix || ".docs"))
    else:)
        (:Otherwise, perform the query.:)
        (: Here the actual query commences. This is split into two parts, the first for a Lucene query and the second for an ngram query. :)
        (:The query passed to a Luecene query in ft:query is an XML element <query> containing one or two <bool>. The <bool> contain the original query and the transliterated query, as indicated by the user in $query-scripts.:)
        let $hitsAll :=
                (:If the $query-scope is narrow, query the elements immediately below the lowest div in tei:text and the four major element below tei:teiHeader.:)
                for $hit at $count in collection ($config:data-root)//tei:placeName[@ref]
                order by $hit ascending(:ft:score($hit) descending:)
                return
                    (:if ($hit/string() != collection ($config:data-root)//tei:placeName[@ref][$count -1]/string()) then:)
                    $hit
                    (:else():)
        let $hitCount := count($hitsAll)
        let $hits := if ($hitCount > 1000) then subsequence($hitsAll, 1, 1000) else $hitsAll
        (:Store the result in the session.:)
        let $store := (
            session:set-attribute($config:session-prefix || ".hits", $hitsAll),
            session:set-attribute($config:session-prefix || ".hitCount", $hitCount)
            (:session:set-attribute($config:session-prefix || ".stype", "places"):)
        )
        return
            app:show-hits($model, $hits,"places")
};

declare function app:searchsources($node as node(), $model as map(*)) {
    (:If there is no query string, fill up the map with existing values:)
   (:if (empty($request?parameters?query))
    then
        app:show-hits($request, session:get-attribute($config:session-prefix || ".hits"), session:get-attribute($config:session-prefix || ".docs"))
    else:)
        (:Otherwise, perform the query.:)
        (: Here the actual query commences. This is split into two parts, the first for a Lucene query and the second for an ngram query. :)
        (:The query passed to a Luecene query in ft:query is an XML element <query> containing one or two <bool>. The <bool> contain the original query and the transliterated query, as indicated by the user in $query-scripts.:)
        let $hitsAll :=
                (:If the $query-scope is narrow, query the elements immediately below the lowest div in tei:text and the four major element below tei:teiHeader.:)
                (:for $hit in collection ($config:data-root)//tei:persName[ancestor::tei:div[@type="sources"]]:)
                for $hit in collection ($config:data-root)//tei:author
                order by $hit ascending(:ft:score($hit) descending:)
                 let $config := tpu:parse-pi(root($hit), $model?parameter?view)
                 let $work := root($hit)/*
                 let $work-title := nav:get-document-title($config, $work)/string()
                return 
                    if ($work-title!= "General Bibliography") then
                    (
                        $hit
                        )
                        else()
        
        
        let $hitCount := count($hitsAll)
        let $hits := if ($hitCount > 1000) then subsequence($hitsAll, 1, 1000) else $hitsAll
        (:Store the result in the session.:)
        let $store := (
            session:set-attribute($config:session-prefix || ".hits", $hitsAll),
            session:set-attribute($config:session-prefix || ".hitCount", $hitCount)
            (:session:set-attribute($config:session-prefix || ".stype", "sources"):)
        )
        return
            app:show-hits($model, $hits,"sources")
};

declare function app:searchevents0($node as node(), $model as map(*)) {
       let $type := request:get-parameter("type","no-value")
       let $q :=console:log($type)
       let $hitsAll :=
                (:If the $query-scope is narrow, query the elements immediately below the lowest div in tei:text and the four major element below tei:teiHeader.:)
                (:for $hit in collection ($config:data-root)//tei:persName[ancestor::tei:div[@type="sources"]]:)
                for $hit in doc($config:events-root||"/events_demo_1.xml")//tei:event
                order by $hit/@type descending(:ft:score($hit) descending:)
                return $hit
       
        let $hitCount := count($hitsAll)
        let $hits := if ($hitCount > 1000) then subsequence($hitsAll, 1, 1000) else $hitsAll
        (:Store the result in the session.:)
        let $store := (
            session:set-attribute($config:session-prefix || ".hits", $hitsAll),
            session:set-attribute($config:session-prefix || ".hitCount", $hitCount)
        )
        return
            app:show-events($model, $hits,'type')
};

declare function app:searchevents($node as node(), $model as map(*)) {
        let $t := request:get-parameter("type","no-value")
        let $type := lower-case(replace($t," ", "-"))
        let $hitsAll :=
                (:If the $query-scope is narrow, query the elements immediately below the lowest div in tei:text and the four major element below tei:teiHeader.:)
                (:for $hit in collection ($config:data-root)//tei:persName[ancestor::tei:div[@type="sources"]]:)
                for $hit in doc($config:events-root||"/events_collection.xml")//tei:event
                where (contains($hit/@type,$type))
                order by $hit/@datingPoint descending
                return $hit
       
        let $hitCount := count($hitsAll)
        let $hits := if ($hitCount > 1000) then subsequence($hitsAll, 1, 1000) else $hitsAll
        (:Store the result in the session.:)
        let $store := (
            session:set-attribute($config:session-prefix || ".hits", $hitsAll),
            session:set-attribute($config:session-prefix || ".hitCount", $hitCount)
        )
        return
            app:show-events($model, $hits,'type')
};

declare function app:searcheventsp($node as node(), $model as map(*)) {
        let $p := request:get-parameter("p","no-value")
        let $hitsAll :=
                for $hit in doc($config:events-root||"/events_collection.xml")//tei:event
                where ($hit//tei:persName[@sameAs=concat("#",$p)])
                order by $hit/@datingPoint descending(:ft:score($hit) descending:)
                return $hit
       
        let $hitCount := count($hitsAll)
        let $hits := if ($hitCount > 1000) then subsequence($hitsAll, 1, 1000) else $hitsAll
        (:Store the result in the session.:)
        let $store := (
            session:set-attribute($config:session-prefix || ".hits", $hitsAll),
            session:set-attribute($config:session-prefix || ".hitCount", $hitCount)
        )
        return
            app:show-events($model, $hits,'sameas')
};


declare function app:searcheventsf($node as node(), $model as map(*)) {
        let $s := request:get-parameter("s","no-value")
        let $subtype := lower-case(replace($s," ", "-"))
        let $hitsAll :=
                (:If the $query-scope is narrow, query the elements immediately below the lowest div in tei:text and the four major element below tei:teiHeader.:)
                (:for $hit in collection ($config:data-root)//tei:persName[ancestor::tei:div[@type="sources"]]:)
                for $hit in doc($config:events-root||"/events_collection.xml")//tei:event
                where ($hit//tei:name[@subtype=$subtype])
                order by $hit/@datingPoint descending(:ft:score($hit) descending:)
                return $hit
       
        let $hitCount := count($hitsAll)
        let $hits := if ($hitCount > 1000) then subsequence($hitsAll, 1, 1000) else $hitsAll
        (:Store the result in the session.:)
        let $store := (
            session:set-attribute($config:session-prefix || ".hits", $hitsAll),
            session:set-attribute($config:session-prefix || ".hitCount", $hitCount)
        )
        return
            app:show-events($model, $hits,'subtype')
};


declare function app:fragtragevents($node as node(), $model as map(*)) {
    (:If there is no query string, fill up the map with existing values:)
   (:if (empty($request?parameters?query))
    then
        app:show-hits($request, session:get-attribute($config:session-prefix || ".hits"), session:get-attribute($config:session-prefix || ".docs"))
    else:)
        (:Otherwise, perform the query.:)
        (: Here the actual query commences. This is split into two parts, the first for a Lucene query and the second for an ngram query. :)
        (:The query passed to a Luecene query in ft:query is an XML element <query> containing one or two <bool>. The <bool> contain the original query and the transliterated query, as indicated by the user in $query-scripts.:)
        let $hitsAll :=
                (:If the $query-scope is narrow, query the elements immediately below the lowest div in tei:text and the four major element below tei:teiHeader.:)
                (:for $hit in collection ($config:data-root)//tei:persName[ancestor::tei:div[@type="sources"]]:)
                for $hit in doc($config:events-root||"/events_collection.xml")//tei:event
                order by $hit/@datingPoint descending(:ft:score($hit) descending:)
                return $hit
       
        let $hitCount := count($hitsAll)
        let $hits := if ($hitCount > 1000) then subsequence($hitsAll, 1, 1000) else $hitsAll
        (:Store the result in the session.:)
        let $store := (
            session:set-attribute($config:session-prefix || ".hits", $hitsAll),
            session:set-attribute($config:session-prefix || ".hitCount", $hitCount)
        )
        return
            app:show-events($model, $hits, 'timeline')
};


declare %private function app:show-hits($model as map(*), $hits as item()*, $stype as xs:string+) {
            <div slot="">
<div><paper-card class="index-cell">
                    <div class="letter"><h3>A</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "A",$stype)}</span>
                </paper-card></div>
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>B</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "B",$stype)}</span>
                </paper-card></div>
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>C</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "C",$stype)}</span>
                </paper-card></div>
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>D</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "D",$stype)}</span>
                </paper-card></div>               
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>E</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "E",$stype)}</span>
                </paper-card></div>                
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>F</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "F",$stype)}</span>
                </paper-card></div>               
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>G</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "G",$stype)}</span>
                </paper-card></div>                
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>H</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "H",$stype)}</span>
                </paper-card></div>                
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>I</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "I",$stype)}</span>
                </paper-card></div>
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>J</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "J",$stype)}</span>
                </paper-card></div>
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>K</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "K",$stype)}</span>
                </paper-card></div>
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>L</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "L",$stype)}</span>
                </paper-card></div>
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>M</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "M",$stype)}</span>
                </paper-card></div>
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>N</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "N",$stype)}</span>
                </paper-card></div>               
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>O</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "O",$stype)}</span>
                </paper-card></div>                
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>P</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "P",$stype)}</span>
                </paper-card></div>               
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>Q</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "Q",$stype)}</span>
                </paper-card></div>                
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>R</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "R",$stype)}</span>
                </paper-card></div>                
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>S</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "S",$stype)}</span>
                </paper-card></div>
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>T</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "T",$stype)}</span>
                </paper-card></div> 
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>U</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "U",$stype)}</span>
                </paper-card></div>
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>V</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "V",$stype)}</span>
                </paper-card></div>
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>W</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "W",$stype)}</span>
                </paper-card></div>
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>X</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "X",$stype)}</span>
                </paper-card></div>               
                <div><paper-card class="index-cell">
                    <div class="letter"><h3>Y</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "Y",$stype)}</span>
                </paper-card></div>                
                 <div><paper-card class="index-cell">
                    <div class="letter"><h3>Z</h3></div> 
                    <span>{app:show-hits-fl($model, $hits, "Z",$stype)}</span>
                </paper-card></div>                   
               </div>
};


declare %private function app:show-hits-fl($model as map(*), $hits as item()*, $fl as xs:string, $stype as xs:string+) {
    response:set-header("pb-total", xs:string(count($hits))),
    response:set-header("pb-start", "1"),
    let $counter :=0
    for $hit at $p in $hits(:subsequence($hits, 1, 10):)
    let $config := tpu:parse-pi(root($hit), $model?parameter?view)
    let $parent := query:get-parent-section($config, $hit)
    let $parent-id := config:get-identifier($parent)
    (:let $parent-id := if (exists($docs)) then replace($parent-id, "^.*?([^/]*)$", "$1") else $parent-id:)
    let $div := query:get-current($config, $parent)
    let $expanded := util:expand($hit, "add-exist-id=all")
    let $docId := config:get-identifier($div)
    let $work := root($hit)/*
    let $work-title := nav:get-document-title($config, $work)/string()
    return 
            if (substring($hit,1,1) = $fl) then
              if($p=1) then
                            <p><a href="search1.html?query={$hit}&amp;stype={$stype}">{$hit}</a></p>
                    else(
                            if ($hit/string() != $hits[$p -1]/string()) then
                                            <p><a href="search1.html?query={$hit}&amp;stype={$stype}">{$hit}</a></p>
                                            
                            else ()
                    )
            else ()
};

declare %private function app:show-hits1($model as map(*), $hits as item()*) {
    response:set-header("pb-total", xs:string(count($hits))),
    response:set-header("pb-start", "1"),
    for $hit at $p in $hits(:subsequence($hits, 1, 10):)
    let $config := tpu:parse-pi(root($hit), $model?parameter?view)
    let $parent := query:get-parent-section($config, $hit)
    let $parent-id := config:get-identifier($parent)
    (:let $parent-id := if (exists($docs)) then replace($parent-id, "^.*?([^/]*)$", "$1") else $parent-id:)
    let $div := query:get-current($config, $parent)
    let $expanded := util:expand($hit, "add-exist-id=all")
    let $docId := config:get-identifier($div)
    let $work := root($hit)/*
    let $work-title := nav:get-document-title($config, $work)/string()
    return 
        if($hit) then
        <paper-card class="index-cell">
                <div class="count">{1 + $p - 1}</div>        
                <!--a href="{$parent-id || "?action=index&amp;root=" || util:node-id($div) || "&amp;view=" || $config?view || "&amp;odd=" || $config?odd}" target="_blank">{$hit}{$work-title}</a-->
                <!--a href="{$parent-id || "#"||$hit}">{$hit}</a-->
                <a href="search1.html?query={$hit}">{$hit}</a>
                { app:get-breadcrumbs($config, $hit, $parent-id) }
        </paper-card>
        else()

};

declare %private function app:show-events($model as map(*), $hits as item()*, $index as xs:string) {
    response:set-header("pb-total", xs:string(count($hits))),
    response:set-header("pb-start", "1"),
    for $hit at $p in $hits(:subsequence($hits, 1, 10):)
    order by $hit/@datingPoint descending(:ft:score($hit) descending:)
    let $config := tpu:parse-pi(root($hit), $model?parameter?view)
    let $parent := query:get-parent-section($config, $hit)
    let $parent-id := config:get-identifier($parent)
    (:let $parent-id := if (exists($docs)) then replace($parent-id, "^.*?([^/]*)$", "$1") else $parent-id:)
    let $div := query:get-current($config, $parent)
    let $expanded := util:expand($hit, "add-exist-id=all")
    let $docId := config:get-identifier($div)
    let $work := root($hit)/*
    let $work-title := nav:get-document-title($config, $work)/string()
    let $ltypes:= "tragic-victory;choregic-tragic-victory;tragic-performance;incident;death"
    return
    if($index='type' or $index='sameas' or $index='subtype')then
     (
        <span>{app:get-event($config,$hit,$parent-id)}</span>
        )
        else(
                if($p mod 2=1) then
                (
                
                
                 <div class="timeline__item timeline__item--right fadeIn">
                 <div class="timeline__item__inner"><div class="timeline__content__wrap"><div class="timeline__content">
                        {app:get-event($config,$hit,$parent-id) }
                 </div></div></div>
                 </div>
                                                
                
               
               )else(
                        
                <div class="timeline__item animated timeline__item--left fadeIn">
                 <div class="timeline__item__inner"><div class="timeline__content__wrap"><div class="timeline__content">
                        {app:get-event($config,$hit,$parent-id) }
                 </div></div></div>
                 </div>
                
                )
            )
};

declare function app:get-event($config as map(*), $hit as node(), $parent-id as xs:string) {
    let $work := root($hit)/*
    let $work-title := nav:get-document-title($config, $work)/string()
    return
                <paper-card class="index-cell" id="{$hit/@xml:id}">
                    <h2>{
                        if(exists($hit/@when)) then
                        (
                           substring($hit/@when,3,3)||' BC'
                        )else
                        (
                            if(exists($hit/@notBefore) and exists($hit/@notAfter) )then
                            (
                                'Between '||substring($hit/@notBefore,3,3)||'  and  '|| substring($hit/@notAfter,3,3)||' BC'
                            )else(
                                if(exists($hit/@notBefore))then
                                (
                                    substring($hit/@notBefore,3,3)||' BC'
                                )else(
                                    if(exists($hit/@notAfter))then
                                    (
                                        substring($hit/@notAfter,3,3)||' BC'
                                    )else(
                                        ' Unknown Date '
                                    )
                                )
                            )
                        )}</h2>
                    <p>{$hit/string()}</p>
                    <p>
                        <ul>
                         {
                                if(exists($hit//tei:persName[@sameAs]) and $hit//tei:persName/@role/string()="tragedian")then
                            <li>Poet(s):
                           {
                                for $z at $count2 in  $hit//tei:persName[@sameAs]
                                where $z[@role="tragedian"]
                                    let $output:=<span><a href="{concat('/exist/apps/fragtrag/','indexesameas.html?p=',replace($z/@sameAs/string(),"#",""))}" rel="noopener">{$z}</a> (<a href="{$z/@ref/string()}" rel="noopener">*</a>){if($count2 < count($hit//tei:persName[@role="tragedian"]))then ", " else()}</span>
                                            return
                                            $output
                                            (:replace($z,replace($z,'#',''), $output):)
                                            (:concat(substring-before($hit/string(),$z/string()),$z/string(), substring-after($hit/string(),$z/string())):)
                           }    
                            </li> else ()
                            }
                            {
                                if(exists($hit//tei:persName[@sameAs]) and $hit//tei:persName/@role/string()="choregus")then
                            <li>Choregus:
                            {
                                for $z at $count2 in  $hit//tei:persName[@sameAs]
                                where  $z[@role="choregus"]
                                    let $output:=<span><a href="{concat('/exist/apps/fragtrag/','indexesameas.html?p=',replace($z/@sameAs/string(),"#",""))}" rel="noopener">{$z}</a> (<a href="{$z/@ref/string()}" rel="noopener">*</a>){if($count2 < count($hit//tei:persName[@role="choregus"]))then ", " else()}</span>
                                            return
                                            $output
                                            (:replace($z,replace($z,'#',''), $output):)
                                            (:concat(substring-before($hit/string(),$z/string()),$z/string(), substring-after($hit/string(),$z/string())):)
                                            }
                                
                            </li>else ()
                            }
                            {
                            if(exists($hit//tei:persName[@sameAs]) and $hit//tei:persName/@role/string()="actor")then
                            <li>Actor:
                            {
                                for $z at $count2 in  $hit//tei:persName[@sameAs]
                                where  $z[@role="actor"]
                                    let $output:=<span><a href="{concat('/exist/apps/fragtrag/','indexesameas.html?p=',replace($z/@sameAs/string(),"#",""))}" rel="noopener">{$z}</a> (<a href="{$z/@ref/string()}" rel="noopener">*</a>){if($count2 < count($hit//tei:persName[@role="actor"]))then ", " else()}</span>
                                            return
                                            $output
                                            (:replace($z,replace($z,'#',''), $output):)
                                            (:concat(substring-before($hit/string(),$z/string()),$z/string(), substring-after($hit/string(),$z/string())):)
                                            }
                                
                            </li>else ()
                            }
                            {
                                if(exists($hit//tei:name[@subtype]))then
                            <li>Festival:
                            {
                                for $z at $count2 in  $hit//tei:name[@subtype]
                                    let $output:=<span><a href="{concat('/exist/apps/fragtrag/','indexesubtype.html?s=',$z/@subtype/string())}" rel="noopener">{$z}</a> (<a href="{$z/@ref/string()}" rel="noopener">*</a>){if($count2 < count($hit//tei:name[@subtype]))then ", " else()}</span>
                                            return
                                            $output
                                            }
                                
                            </li>else ()
                            }
                            <li>Type: 
                                {if(exists($hit/@type))then 
                                    
                                        for $x at $count0 in tokenize($hit/@type,';') 
                                        return
                                            <a href="{concat('/exist/apps/fragtrag/','indexe.html?type=',$x)}" rel="noopener">{replace($x,'-', ' ')} {if($count0 < count(tokenize($hit/@type,';')))then ", " else()}</a>
                                    
                                 else ('-')}</li>
                           
                            <li>Source(s): 
                                {if(exists($hit/@source))then 
                                for $y at $count1 in tokenize($hit/@source,' ') 
                                return
                                <span>
                                   {if(substring-before(substring-after($y,"-"),"-")='test')then
                                    (
                                        <a href="{concat('/exist/apps/fragtrag/',lower-case(replace(substring-before($y,"-"),'#','')),'/testimonia/',replace(substring-before($y,"-"),'#',''),'_TESTIMONIA.xml',$y)}" target="_blank">{(if(replace(substring-before($y,"-"),'#','')="Aristarchustegeates")then "Aristarchus Tegeates" else(replace(substring-before($y,"-"),'#','')))|| ' Test. ' ||  tokenize($y,'-')[3]}</a>
                                    )
                                    else(
                                        <a href="{concat('/exist/apps/fragtrag/',lower-case(replace(substring-before($y,"-"),'#','')),'/fragmenta/',replace(substring-before($y,"-"),'#',''),'_FRAGMENTA.xml',$y)}" target="_blank">{(if(replace(substring-before($y,"-"),'#','')="Aristarchustegeates")then "Aristarchus Tegeates" else(replace(substring-before($y,"-"),'#','')))|| ' Frag. ' ||  tokenize($y,'-')[3]}</a>
                                    )} {if($count1 < count(tokenize($hit/@source,' ')))then ", " else()}</span>
                                else ('-')}</li>
                            
                            {if(exists($hit/@corresp))then 
                            <li><p>Corresponding event(s): <a href="{$hit/@corresp}">{substring-before(doc($config:events-root||"/events_demo_1.xml")//tei:event[@xml:id=substring-after($hit/@corresp,'#')],'.')}</a></p></li> 
                            else ()}
                        </ul>
                    </p>
                </paper-card>   
};

declare function app:get-breadcrumbs($config as map(*), $hit as node(), $parent-id as xs:string) {
    let $work := root($hit)/*
    let $work-title := nav:get-document-title($config, $work)/string()
    return
        <div class="breadcrumbs">
            <a class="breadcrumb" href="{$parent-id}">{$work-title}</a>
            {
                for $parentDiv in $hit/ancestor-or-self::tei:div[tei:head/text()[1]] (:ntaliakouras @20230715 for shortenning notes:)
                let $id := util:node-id(
                    if ($config?view = "page") then ($parentDiv/preceding::tei:pb[1], $parentDiv)[1] else $parentDiv
                )
                return
                    if (contains ($parentDiv/tei:head/string(), "Translation")) then 
                    (
                    <a class="breadcrumb" href="{$parent-id || "?action=index&amp;root=" || $id || "&amp;view=" || $config?view || "&amp;odd=" || $config?odd}">
                    {substring($parentDiv/tei:head/string(), 0, 12)}
                    
                    </a>
                    )
                    else(
                    <a class="breadcrumb" href="{$parent-id || "?action=index&amp;root=" || $id || "&amp;view=" || $config?view || "&amp;odd=" || $config?odd}">
                    {$parentDiv/tei:head/string()}
                    
                    </a>
                    )
            }
        </div>
};


declare function app:fragtragcitation($node as node(), $model as map(*)) {
     let $doc := 
    if(contains(substring-after(request:get-uri(),"/exist/apps/fragtrag"),"event")) then(
        doc($config:events-root||"/events_demo_1.xml")
    )else(
        doc(concat($config:data-root, substring-after(request:get-uri(),"/exist/apps/fragtrag")))
    )
let $title := $doc//tei:titleStmt//tei:title//text()
let $pd := $doc//tei:projectDesc[tei:p]//text()
let $visited := current-date()
let $link := request:get-url()
return
<div class="popup" onclick="myFunction()"> <strong>CITE </strong> <i class="fa fa-quote-left"></i>
 <span class="popuptext" id="myPopup">
 <span id="myInput">
{
let $names := $doc//tei:name[@ref]
            for $y at $count1 in $names
            let $listnames :=
            <span>
                {if($count1 < count($names))then $y||",  " else($y)}
            </span>
            return
                <span>{$listnames}</span>
 }           
 <span>, "{$title}", in: {$pd} (visited on {$visited}, retrieved from: {$link})</span></span><button onclick="myFunction1()"><i class="fa fa-clipboard" aria-hidden="true"></i></button></span>
</div>

   
};



declare function app:concordance($node as node(), $model as map(*)) {
        let $hitsAll :=
                for $hit in doc($config:concordance-root||"/concordance.xml")//div1
                order by $hit/@type descending(:ft:score($hit) descending:)
                return $hit
       
        let $hitCount := count($hitsAll)
        let $hits := if ($hitCount > 1000) then subsequence($hitsAll, 1, 1000) else $hitsAll
        (:Store the result in the session.:)
        let $store := (
            session:set-attribute($config:session-prefix || ".hits", $hitsAll),
            session:set-attribute($config:session-prefix || ".hitCount", $hitCount)
        )
        return
            app:show-concordance($model, $hits)
};

declare %private function app:show-concordance($model as map(*), $hits as item()*) {
    for $hit at $p in $hits
    return
                <paper-card class="index-cell" id="{$hit/@xml:id}">
                    <button class="collapsible">{$hit/@n/string()}</button>
                    <div class="content">
                    <p>
                    {
                    let $types := $hit/div2
                     for $type in $types
                        return
                        <span>
                           <h2><i>{$type/@type/string()}</i></h2>
                            <table>
                              <tr>
                                <th>FragTrag</th>
                                <th>TGRF</th>
                              </tr>
                            {
                            let $entries := $type/entry
                            for $entry in $entries
                            return
                            <tr>
                                <td>
                                {
                                if(exists($entry/fragtrag/@corresp))then 
                                for $y at $count1 in tokenize($entry/fragtrag/@corresp,' ') 
                                return
                                <span>
                                   {if(substring-before(substring-after($y,"-"),"-")='test')then
                                    (
                                        <a href="{concat('/exist/apps/fragtrag/',lower-case(replace(substring-before($y,"-"),'#','')),'/testimonia/',replace(substring-before($y,"-"),'#',''),'_TESTIMONIA.xml',$y)}" target="_blank">{$entry/fragtrag/text()}</a>
                                    )
                                    else(
                                        <a href="{concat('/exist/apps/fragtrag/',lower-case(replace(substring-before($y,"-"),'#','')),'/fragmenta/',replace(substring-before($y,"-"),'#',''),'_FRAGMENTA.xml',$y)}" target="_blank">{$entry/fragtrag/text()}</a>
                                    )} {if($count1 < count(tokenize($entry/fragtrag/@corresp,' ')))then ", " else()}</span>
                                else ('-')
                                }
                                </td>
                                <td>{$entry/tgrf/string()}</td>
                            </tr>
                            }

                            </table>
                        </span>
                    }
                    </p>
                    </div>
                </paper-card>  
};
